mlpy.predictions package
========================

.. automodule:: mlpy.predictions
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   mlpy.predictions.base
   mlpy.predictions.classification
   mlpy.predictions.regression
